###############################################################################
###############################################################################
##
##  Copyright (C) 2004 Red Hat, Inc.  All rights reserved.
##
##  This copyrighted material is made available to anyone wishing to use,
##  modify, copy, or redistribute it subject to the terms and conditions
##  of the GNU General Public License v.2.
##
###############################################################################
###############################################################################
%define _unpackaged_files_terminate_build 1

%{!?kernel: %{expand: %%define kernel %(uname -r)}}
%define kversion %(echo %{kernel} | sed -e s/smp// -)

%define kernel_ver_str %(echo %{kversion} | tr -s '-' '_')

%define kmajor %(echo %{kversion} | cut -d'-' -f1)
%define kminor %(echo %{kversion} | cut -d'-' -f2)
%if %(echo %{kernel} | grep -c smp)
        %{expand:%%define ksmp -smp}
%endif
%define kconfig  /usr/src/linux-%(echo %{kernel})/configs/kernel-%{kmajor}-i686%{?ksmp}.config


%define KERNEL_VERSION 2
%define KERNEL_PATCHLEVEL 4
%define KERNEL_SUBLEVEL 21
%define KERNEL_EXTRAVERSION %{kminor}
%define kernel_version %{KERNEL_VERSION}.%{KERNEL_PATCHLEVEL}.%{KERNEL_SUBLEVEL}-%{KERNEL_EXTRAVERSION}

%define buildup 1
%define buildsmp 1
%define buildhugemem 1

%ifnarch i686
%define buildhugemem 0
%endif

%ifnarch i686 x86_64 athlon
%define buildsmp 0
%endif 

%define mrelease 2.PU_IAS.1WS

Name: ndiswrapper
Version: 0.12
Release: %{mrelease}
License: GPL
GROUP: System Environment/Base
Summary: ndiswrapper allows you to use windows XP drivers for that WLAN card without proper Linux drivers.
BuildRequires: rsync flex bison
BuildRequires: kernel-source = %{kernel_version}
ExcludeArch: i386 ppc ppc64 s390 s390x
URL: http://ndiswrapper.sourceforge.net
Source0: %{name}-%{version}.tar.gz

# Patches are applied later - after the source is extracted
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
ome wireless LAN vendors refuse to release hardware specifications or
drivers for their products for operating systems other than Microsoft
Windows. The ndiswrapper project makes it possible to use such
hardware with Linux by means of a loadable kernel module that "wraps
around" NDIS (Windows network driver API) drivers.  This rpm contains
just the userspace tools. You will also need the kernel module rpm.

%if %{buildup}
%package modules
GROUP: System Environment/Base
Summary: Ndiswrapper kernel module
Release: %{mrelease}.%{KERNEL_VERSION}.%{KERNEL_PATCHLEVEL}.%{KERNEL_SUBLEVEL}_%{KERNEL_EXTRAVERSION}
Requires: kernel = %{kernel_version}
Requires: ndiswrapper
Provides: kernel-module kernel-modules

%description modules
Kernel module for ndiswrapper.
%endif

%if %{buildsmp}
%package modules-smp
GROUP: System Environment/Base
Summary: Ndiswrapper kernel module
Release: %{mrelease}.%{KERNEL_VERSION}.%{KERNEL_PATCHLEVEL}.%{KERNEL_SUBLEVEL}_%{KERNEL_EXTRAVERSION}
Requires: %{name} = %{version}-%{release}
Requires: kernel-smp = %{kernel_version}
Requires: ndiswrapper
Provides: kernel-module kernel-modules

%description modules-smp
Kernel module for ndiswrapper.
%endif

%if %{buildhugemem}
%package modules-hugemem
GROUP: System Environment/Base
Summary: Ndiswrapper kernel module
Release: %{mrelease}.%{KERNEL_VERSION}.%{KERNEL_PATCHLEVEL}.%{KERNEL_SUBLEVEL}_%{KERNEL_EXTRAVERSION}
Requires: %{name} = %{version}-%{release}
Requires: kernel-hugemem = %{kernel_version}
Requires: ndiswrapper
Provides: kernel-module kernel-modules

%description modules-hugemem
Kernel module for ndiswrapper.
%endif

####################################################################################
##  THE PREP SECTION
####################################################################################
%prep
echo ping
%setup -q
echo pong
####################################################################################
##  THE BUILD SECTION
####################################################################################
%build
BUILD_TOPDIR=`pwd`

BuildSistina(){
	cpu_type=$1
	flavor=$2
	kernel_src=/usr/src/linux-%{kernel_version}
	# Kernel tree setup
	if [ -d $kernel_src/. ]; then
		echo "Kernel found."
	else
		echo "Kernel not found."
		ls /lib/modules/2.4.21-*EL
		exit 1
	fi

	rsync -aH $kernel_src/ linux$flavor
	make -C linux$flavor mrproper
	[ -d linux$flavor/configs ] || exit 1
#	cat > linux$flavor/.config <<EOF
#CONFIG_IPW2100=m
#EOF
	cat linux$flavor/configs/kernel*${cpu_type}${flavor:+-}$flavor.config >> linux$flavor/.config
	make -C linux$flavor oldconfig \
		VERSION=%{KERNEL_VERSION} \
		PATCHLEVEL=%{KERNEL_PATCHLEVEL} \
		SUBLEVEL=%{KERNEL_SUBLEVEL} \
		EXTRAVERSION=-%{KERNEL_EXTRAVERSION}$flavor

	make -C linux$flavor dep \
		VERSION=%{KERNEL_VERSION} \
		PATCHLEVEL=%{KERNEL_PATCHLEVEL} \
		SUBLEVEL=%{KERNEL_SUBLEVEL} \
		EXTRAVERSION=-%{KERNEL_EXTRAVERSION}$flavor

	make KSRC=`pwd`/linux$flavor KVERS=%{kernel_version}$flavor
	mkdir ../installed-$flavor
	# make install KSRC=`pwd`/linux$flavor KVERS=%{kernel_version}$flavor KMISC=installed-$flavor
	mv ndiswrapper.o ../installed-$flavor
	make clean
	rm -rf linux$flavor

	# Build it!
	#make %{?_smp_mflags} ${flavor:-NO_FLAVOR}=y \
#		VERSION=%{KERNEL_VERSION} \
#		PATCHLEVEL=%{KERNEL_PATCHLEVEL} \
#		SUBLEVEL=%{KERNEL_SUBLEVEL} \
#		EXTRAVERSION=-%{KERNEL_EXTRAVERSION}$flavor
}

cd driver

%if %{buildhugemem}
BuildSistina %{_target_cpu} hugemem
%endif

%if %{buildsmp}
BuildSistina %{_target_cpu} smp
%endif

%if %{buildup}
BuildSistina %{_target_cpu}
%endif

cd ..

# finally, make the utilities
make -C utils

####################################################################################
##  THE INSTALL SECTION
####################################################################################
%install
rm -rf $RPM_BUILD_ROOT
doinstall() {
	flavor=$1
	mkdir -p $RPM_BUILD_ROOT/lib/modules/%{kernel_version}$flavor/kernel/drivers/misc/
	cp installed-$flavor/* $RPM_BUILD_ROOT/lib/modules/%{kernel_version}$flavor/kernel/drivers/misc
}

%if %{buildhugemem}
doinstall hugemem
%endif

%if %{buildsmp}
doinstall smp
%endif

%if %{buildup}
doinstall
%endif

cd utils
mkdir -p $RPM_BUILD_ROOT/sbin
mkdir -p $RPM_BUILD_ROOT/usr/sbin
install -m 755 loadndisdriver $RPM_BUILD_ROOT/sbin
install -m 755 ndiswrapper ndiswrapper-buginfo $RPM_BUILD_ROOT/usr/sbin

####################################################################################
##  THE CLEAN SECTION
####################################################################################
%clean
rm -rf $RPM_BUILD_ROOT


####################################################################################
##  THE POST/POSTUN SECTION
####################################################################################
%if %{buildup}
%post modules
depmod -a

%postun modules
depmod -a
%endif

%if %{buildsmp}
%post modules-smp
depmod -a

%postun modules-smp
depmod -a
%endif

%if %{buildhugemem}
%post modules-hugemem
depmod -a

%postun modules-hugemem
depmod -a
%endif

%files
%defattr(0755,root,root)
%doc README AUTHORS ChangeLog INSTALL
/sbin/*
/usr/sbin/*

%if %{buildup}
%files modules
%defattr(-,root,root,-)
# Modules
/lib/modules/%{kernel_version}/kernel/drivers/misc/*
%endif

%if %{buildsmp}
%files modules-smp
%defattr(-,root,root,-)
# Modules
/lib/modules/%{kernel_version}smp/kernel/drivers/misc/*
%endif

%if %{buildhugemem}
%files modules-hugemem
%defattr(-,root,root,-)
# Modules
/lib/modules/%{kernel_version}hugemem/kernel/drivers/misc/*
%endif

%changelog
* Mon Aug 2 2004 Josko Plazonic <plazonic@math.princeton.edu>
- first build
